<?php
/**
 * Mozilla atoswiki theme
 * Modified by Dick Pluim for MW 1.23
 *
 * Loosely based on the Cavendish style by DaSch 
 *
 * @todo document
 * @package MediaWiki
 * @subpackage Skins
 *
 * History:
 *
 * 2015-01-30 Added . (dot) in TOC and autonumbered headings
 * 2015-01-26 Minor updates
 * 2015-01-23 Initial release, modification of Cavendish style
 *
 */


class AtosWikiTemplate extends MonoBookTemplate {
	var $skin;
	/**
	 * Template filter callback for atoswiki skin.
	 * Takes an associative array of data set from a SkinTemplate-based
	 * class, and a wrapper for MediaWiki's localization database, and
	 * outputs a formatted page.
	 *
	 * @access private
	 */
	function execute() {
		global $wgRequest, $wgLang;
		global $atoswikiQRCode;
		if (!isset($atoswikiQRCode)) {
			$atoswikiQRCode = false;
		}
		$styleversion = '2015.01.26';
		$this->skin = $skin = $this->data['skin'];
		$action = $wgRequest->getText( 'action' );
		if ( $action == "") {
			$action = "view";
		}
		// Suppress warnings to prevent notices about missing indexes in $this->data
		wfSuppressWarnings();
		$this->html( 'headelement' );
?>
<div id="internal"></div>
<!-- Skin-Version: <?php echo $styleversion ?> //Please leave this for bugtracking purpose//-->
<div id="globalWrapper" class="<?php echo $action ?>">
	<div id="p-personal" class="portlet">
		<h5><?php $this->msg('personaltools') ?></h5>
		<div class="pBody">
			<ul <?php $this->html('userlangattributes') ?>>
			<?php foreach($this->data['personal_urls'] as $key => $item) {?>
			
			<li id="<?php echo Sanitizer::escapeId( "pt-$key" ) ?>" class="<?php
					if ($item['active']) { ?>active <?php } ?>top-nav-element">
				<span class="top-nav-left">&nbsp;</span>
				<a class="top-nav-mid <?php echo htmlspecialchars($item['class']) ?>" 
				   href="<?php echo htmlspecialchars($item['href']) ?>">
				   <?php echo htmlspecialchars($item['text']) ?></a>	
				<span class="top-nav-right">&nbsp;</span></li>
				<?php
				} ?>
			
			</ul>
		</div>
	</div>
	<div id="header">
		<a name="top" id="contentTop"></a>
		<h6>
		<a
		href="<?php echo htmlspecialchars($this->data['nav_urls']['mainpage']['href'])?>"
		title="<?php $this->msg('mainpage') ?>"><?php $this->text('pagetitle') ?></a></h6>
		<div id="p-cactions" class="portlet"><ul>
<?php			foreach($this->data['content_actions'] as $key => $tab) {
					echo '
				<li id="' . Sanitizer::escapeId( "ca-$key" ) . '"';
					if( $tab['class'] ) {
						echo ' class="'.htmlspecialchars($tab['class']).'"';
					}
					echo '><a href="'.htmlspecialchars($tab['href']).'"';
					# We don't want to give the watch tab an accesskey if the
					# page is being edited, because that conflicts with the
					# accesskey on the watch checkbox.  We also don't want to
					# give the edit tab an accesskey, because that's fairly su-
					# perfluous and conflicts with an accesskey (Ctrl-E) often
					# used for editing in Safari.
					if( in_array( $action, array( 'edit', 'submit' ) ) && in_array( $key, array( 'edit', 'watch', 'unwatch' ) ) ) {
						echo $skin->tooltip( "ca-$key" );
					}
					else {
						echo $skin->tooltip( "ca-$key" );
					}
					echo '>'.htmlspecialchars($tab['text']).'</a></li>';
				}
								
				?>
			</ul></div>
			<?php $this->searchBox(); ?>
	</div>
	<div id="mBody">
		<div id="side">
			<div id="nav">
<?php //sidebar
      $this->renderPortals( $this->data['sidebar'] );
?>

</div>
</div>
		</div><!-- end of SIDE div -->
		<div id="column-content">
			<div id="content">
				<a id="top"></a>
				<?php if($this->data['sitenotice']) { ?><div id="siteNotice"><?php $this->html('sitenotice') ?></div><?php } ?>
				<h1 id="firstHeading" class="firstHeading"><?php $this->html('title') ?></h1>
				<div id="bodyContent">
					<h3 id="siteSub"><?php $this->msg('tagline') ?></h3>
					<div id="contentSub"><?php $this->html('subtitle') ?></div>
					<?php if($this->data['undelete']) { ?><div id="contentSub2"><?php $this->html('undelete') ?></div><?php } ?>
					<?php if($this->data['newtalk'] ) { ?><div class="usermessage"><?php $this->html('newtalk')  ?></div><?php } ?>
					<?php if($this->data['showjumplinks']) { ?><div id="jump-to-nav"><?php $this->msg('jumpto') ?> <a href="#column-one"><?php $this->msg('jumptonavigation') ?></a>, <a href="#searchInput"><?php $this->msg('jumptosearch') ?></a></div><?php } ?>
					<!-- start content -->
					<?php $this->html('bodytext') ?>
					<?php if($this->data['catlinks']) { $this->html('catlinks'); } ?>
					<!-- end content -->
					<?php if($this->data['dataAfterContent']) { $this->html ('dataAfterContent'); } ?>
				</div>
			</div><!-- end of MAINCONTENT div -->	
		</div>
	</div><!-- end of MBODY div -->
	<div class="visualClear"></div>
	<div id="footer">
		<table>
			<tr>
				<td rowspan="2" class="f-iconsection">
		<?php //copytight icon
		if($this->data['copyrightico']) { ?><div id="f-copyrightico"><?php $this->html('copyrightico') ?></div><?php } ?>
				</td>
				<td align="center">
<?php	// Generate additional footer links
		$footerlinks = array(
			'lastmod', 'viewcount', 'numberofwatchingusers', 'credits', 'copyright',
//			'privacy', 'about', 'disclaimer', 'tagline',
                        'tagline',
		);
		$validFooterLinks = array();
		foreach( $footerlinks as $aLink ) {
			if( isset( $this->data[$aLink] ) && $this->data[$aLink] ) {
				$validFooterLinks[] = $aLink;
			}
		}
		if ( count( $validFooterLinks ) > 0 ) {
?>			<ul id="f-list">
<?php
			foreach( $validFooterLinks as $aLink ) {
				if( isset( $this->data[$aLink] ) && $this->data[$aLink] ) {
?>					<li id="f-<?php echo$aLink?>"><?php $this->html($aLink) ?></li>
<?php 			}
			}
		}
?></ul></td>
				<td rowspan="2" class="f-iconsection">
					<?php
					$validFooterIcons = $this->getFooterIcons( "nocopyright" );
					foreach ( $validFooterIcons as $blockName => $footerIcons ) { ?>
							<div id="f-<?php echo htmlspecialchars($blockName); ?>ico"><?php
						foreach ( $footerIcons as $icon ) {
							echo $this->skin->makeFooterIcon( $icon );
							}
					}
					?></div>
					<?php 
					// QR-Code added on option
					if ($atoswikiQRCode) { ?>
					<div id="qrcode">
						<a href="http://goqr.me/" style="border:0 none;cursor:default;text-decoration:none;"><img src="http://api.qrserver.com/v1/create-qr-code/?data=<?php echo htmlentities(Title::newFromText( $wgRequest->getVal( 'title' ))->getFullURL()); ?>&#38;size=60x60" alt="QR Code generator" title="" /></a>
					</div>
					<?php } ?> 
				</td>
			</tr>
			<tr>
				<td><div id="skin-info">
					Mozilla AtosWiki Theme based on the Cavendish style by DaSch modified by Dick Pluim for the Atos OracleWiki</a><br/>
					Skin-Version: <?php echo $styleversion ?>
				</div></td>
			</tr>
		</table>
	</div><!-- end of the FOOTER div -->
</div><!-- end of the CONTAINER div -->
<!-- scripts and debugging information -->
<?php

		$this->printTrail();
		echo Html::closeElement( 'body' );
		echo Html::closeElement( 'html' );
		wfRestoreWarnings();
	}

        /*************************************************************************************************/

        protected function renderPortals( $sidebar ) {
                if ( !isset( $sidebar['SEARCH'] ) ) $sidebar['SEARCH'] = true;
                if ( !isset( $sidebar['TOOLBOX'] ) ) $sidebar['TOOLBOX'] = true;
                if ( !isset( $sidebar['LANGUAGES'] ) ) $sidebar['LANGUAGES'] = true;

                foreach( $sidebar as $boxName => $content ) {
                        if ( $content === false )
                                continue;

                        if ( $boxName == 'SEARCH' ) {
//                                $this->searchBox();
                        } elseif ( $boxName == 'TOOLBOX' ) {
                                $this->toolbox();
                        } elseif ( $boxName == 'LANGUAGES' ) {
//                                $this->languageBox();
                        } else {
                                $this->customBox( $boxName, $content );
                        }
                }
        }

        /*************************************************************************************************/
        function toolbox() {
?>
        <div class="portlet" id="p-tb">
                <h5><?php $this->msg('toolbox') ?></h5>
                <div class="pBody">
                        <ul>
<?php
                foreach ( $this->getToolbox() as $key => $tbitem ) { ?>
                                <?php echo $this->makeListItem($key, $tbitem); ?>

<?php
                }
                wfRunHooks( 'MonoBookTemplateToolboxEnd', array( &$this ) );
                wfRunHooks( 'SkinTemplateToolboxEnd', array( &$this, true ) );
?>
                        </ul>
                </div>
        </div>
<?php
        }

        function searchBox() {
                global $wgUseTwoButtonsSearchForm;
?>
        <div id="p-search" class="portlet">
                <h5><label for="searchInput"><?php $this->msg('search') ?></label></h5>
                <div id="searchBody" class="pBody">
                        <form action="<?php $this->text('wgScript') ?>" id="searchform">
                                <input type='hidden' name="title" value="<?php $this->text('searchtitle') ?>"/>
                                <?php echo $this->makeSearchInput(array( "id" => "searchInput" )); ?>

                                <?php echo $this->makeSearchButton("go", array( "id" => "searchGoButton", "class" => "searchButton" ));
                                if ($wgUseTwoButtonsSearchForm): ?>&#160;
                                <?php echo $this->makeSearchButton("fulltext", array( "id" => "mw-searchButton", "class" => "searchButton" ));
                                else: ?>

                                <div><a href="<?php $this->text('searchaction') ?>" rel="search"><?php $this->msg('powersearch-legend') ?></a></div><?php
                                endif; ?>

                        </form>
                </div>
        </div>
<?php
        }

        /**
         * Prints the cactions bar.
         * Shared between MonoBook and Modern
         */
        function cactions() {
?>
        <div id="p-cactions" class="portlet">
                <h5><?php $this->msg('views') ?></h5>
                <div class="pBody">
                        <ul><?php
                                foreach($this->data['content_actions'] as $key => $tab) {
                                        echo '
                                ' . $this->makeListItem( $key, $tab );
                                } ?>

                        </ul>
                </div>
        </div>
<?php
        }

        /*************************************************************************************************/
        function customBox( $bar, $cont ) {
                $portletAttribs = array( 'class' => 'generated-sidebar portlet', 'id' => Sanitizer::escapeId( "p-$bar" ) );
                $tooltip = Linker::titleAttrib( "p-$bar" );
                if ( $tooltip !== false ) {
                        $portletAttribs['title'] = $tooltip;
                }
                echo '  ' . Html::openElement( 'div', $portletAttribs );
?>

                <h5><?php $msg = wfMessage( $bar ); echo htmlspecialchars( $msg->exists() ? $msg->text() : $bar ); ?></h5>
                <div class='pBody'>
<?php   if ( is_array( $cont ) ) { ?>
                        <ul>
<?php                   foreach($cont as $key => $val) { ?>
                                <?php echo $this->makeListItem($key, $val); ?>

<?php                   } ?>
                        </ul>
<?php   } else {
                        # allow raw HTML block to be defined by extensions
                        print $cont;
                }
?>
                </div>
        </div>
<?php
        }

        /*************************************************************************************************/

} // end of class
